@@ -5,13 +5,13 @@ from genomepy.utils import mkdir_p, cmd_ok, run_index_cmd
 
 
 class Minimap2Plugin(Plugin):
-    def after_genome_download(self, genome, force=False):
+    def after_genome_download(self, genome, threads=1, force=False):
         if not cmd_ok("minimap2"):
             return
 
         # Create index dir
-        index_dir = genome.props["minimap2"]["index_dir"]
-        index_name = genome.props["minimap2"]["index_name"]
+        index_dir = genome.plugin["minimap2"]["index_dir"]
+        index_name = genome.plugin["minimap2"]["index_name"]
         if force:
             # Start from scratch
             rmtree(index_dir, ignore_errors=True)
@@ -19,7 +19,7 @@ class Minimap2Plugin(Plugin):
 
         if not any(fname.endswith(".mmi") for fname in os.listdir(index_dir)):
             # Create index
-            cmd = "minimap2 -d {} {}".format(index_name, genome.filename)
+            cmd = f"minimap2 -t {threads} -d {index_name} {genome.filename}"
             run_index_cmd("minimap2", cmd)
 
     def get_properties(self, genome):
@@ -31,7 +31,7 @@ class Minimap2Plugin(Plugin):
                 os.path.dirname(genome.filename),
                 "index",
                 "minimap2",
-                "{}.mmi".format(genome.name),
+                f"{genome.name}.mmi",
             ),
         }
         return props
